==> 0.0.1.tar.gz: lib/calculator_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class CalculatorPlugin {
  static const MethodChannel _channel =
      const MethodChannel('calculator_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  static Future<Null> calculatorAdd(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "add");
    await _channel.invokeMethod('calculatorAdd', args);
    return null;
  }

  static Future<Null> calculatorsub(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "sub");
    await _channel.invokeMethod('calculatorSub', args);
    return null;
  }

  static Future<Null> calculatormul(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "mul");
    await _channel.invokeMethod('calculatorMul', args);
    return null;
  }

  static Future<Null> calculatordiv(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "div");
    await _channel.invokeMethod('calculatorDiv', args);
    return null;
  }

}

==> 0.0.2.tar.gz: lib/calculator_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class CalculatorPlugin {
  static const MethodChannel _channel =
      const MethodChannel('calculator_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }


  static Future<int> calculatorAdd(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "add");
    await _channel.invokeMethod('calculatorAdd', args);
    return num1+num2;
  }


  static Future<int> calculatorsub(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "sub");
    await _channel.invokeMethod('calculatorSub', args);
    return num1-num2;
  }

  static Future<int> calculatormul(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "mul");
    await _channel.invokeMethod('calculatorMul', args);
    return num1*num2;
  }

  static Future<int> calculatordiv(int num1,int num2) async {
    Map<String, dynamic> args = <String, dynamic>{};
    args.putIfAbsent("num1", () => num1);
    args.putIfAbsent("num2", () => num2);
    args.putIfAbsent("operation", () => "div");
    await _channel.invokeMethod('calculatorDiv', args);
    return num1 ~/num2;
  }



}
